==> hadoop-hdfs-2.6.0-test-sources.jar: org/apache/hadoop/hdfs/server/namenode/TestClusterJspHelper.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hdfs.server.namenode;

import static org.junit.Assert.*;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hdfs.MiniDFSCluster;
import org.apache.hadoop.hdfs.server.namenode.ClusterJspHelper.ClusterStatus;
import org.apache.hadoop.hdfs.server.namenode.ClusterJspHelper.DecommissionStatus;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class TestClusterJspHelper {

  private MiniDFSCluster cluster;
  private Configuration conf;
    
  @Before
  public void setUp() throws Exception {
    conf = new Configuration();  
    cluster = new MiniDFSCluster.Builder(conf).build();
    cluster.waitClusterUp();
  }

  @After
  public void tearDown() throws Exception {
    if (cluster != null)
      cluster.shutdown();    
  }
  
  @Test(timeout = 15000)
  public void testClusterJspHelperReports() {
    ClusterJspHelper clusterJspHelper = new ClusterJspHelper();
    ClusterStatus clusterStatus = clusterJspHelper
     .generateClusterHealthReport();
    assertNotNull("testClusterJspHelperReports ClusterStatus is null",
        clusterStatus);       
    DecommissionStatus decommissionStatus = clusterJspHelper
        .generateDecommissioningReport();
    assertNotNull("testClusterJspHelperReports DecommissionStatus is null",
        decommissionStatus);    
  }
}

==> hadoop-hdfs-2.8.2.6-20181104.092007-37-test-sources.jar: org/apache/hadoop/hdfs/server/namenode/TestClusterJspHelper.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hdfs.server.namenode;

import static org.junit.Assert.*;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hdfs.MiniDFSCluster;
import org.apache.hadoop.hdfs.server.namenode.ClusterJspHelper.ClusterStatus;
import org.apache.hadoop.hdfs.server.namenode.ClusterJspHelper.DecommissionStatus;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class TestClusterJspHelper {

  private MiniDFSCluster cluster;
  private Configuration conf;
    
  @Before
  public void setUp() throws Exception {
    conf = new Configuration();  
    cluster = new MiniDFSCluster.Builder(conf).build();
    cluster.waitClusterUp();
  }

  @After
  public void tearDown() throws Exception {
    if (cluster != null)
      cluster.shutdown();    
  }
  
  @Test(timeout = 15000)
  public void testClusterJspHelperReports() {
    ClusterJspHelper clusterJspHelper = new ClusterJspHelper(cluster.getNameNode());
    ClusterStatus clusterStatus = clusterJspHelper
     .generateClusterHealthReport();
    assertNotNull("testClusterJspHelperReports ClusterStatus is null",
        clusterStatus);       
    DecommissionStatus decommissionStatus = clusterJspHelper
        .generateDecommissioningReport();
    assertNotNull("testClusterJspHelperReports DecommissionStatus is null",
        decommissionStatus);    
  }
}
